@@ -17,7 +17,6 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Any, Callable, List, Set, Union
 
 from typing_extensions import Literal
-
 from supertokens_python.logger import get_maybe_none_as_str, log_debug_message
 
 from .constants import (FDI_KEY_HEADER, RID_KEY_HEADER, TELEMETRY,
@@ -33,7 +32,7 @@ from .recipe.session.cookie_and_header import (
     attach_id_refresh_token_to_cookie_and_header,
     attach_refresh_token_to_cookie, clear_cookies, set_front_token_in_headers)
 from .types import ThirdPartyInfo, User, UsersResponse
-from .utils import (get_rid_from_request, is_version_gte,
+from .utils import (execute_async, get_rid_from_request, is_version_gte,
                     normalise_http_method, send_non_200_response)
 
 if TYPE_CHECKING:
@@ -175,6 +174,7 @@ class Supertokens:
             app_info.website_base_path,
             mode
         )
+        self._telemetry_status: str = 'NONE'
         log_debug_message("Started SuperTokens with debug logging (supertokens.init called)")
         log_debug_message("app_info: %s", self.app_info.toJSON())
         log_debug_message("framework: %s", framework)
@@ -190,13 +190,22 @@ class Supertokens:
             map(lambda func: func(self.app_info), recipe_list))
 
         if telemetry is None:
+            # If telemetry is not provided, enable it by default for production environment
             telemetry = ('SUPERTOKENS_ENV' not in environ) or (
                 environ['SUPERTOKENS_ENV'] != 'testing')
 
         if telemetry:
-            _ = self.send_telemetry()
+            execute_async(self.app_info.mode, self.send_telemetry)
 
     async def send_telemetry(self):
+        # If telemetry is enabled manually and the app is running in testing mode,
+        # do not send the telemetry
+        skip_telemetry = ('SUPERTOKENS_ENV' in environ) and (
+            environ['SUPERTOKENS_ENV'] == 'testing')
+        if skip_telemetry:
+            self._telemetry_status = 'SKIPPED'
+            return
+
         try:
             querier = Querier.get_instance(None)
             response = await querier.send_get_request(NormalisedURLPath(TELEMETRY), {})
@@ -216,8 +225,10 @@ class Supertokens:
             async with AsyncClient() as client:
                 await client.post(url=TELEMETRY_SUPERTOKENS_API_URL, json=data,  # type: ignore
                                   headers={'api-version': TELEMETRY_SUPERTOKENS_API_VERSION})
+
+            self._telemetry_status = 'SUCCESS'
         except Exception:
-            pass
+            self._telemetry_status = 'EXCEPTION'
 
     @staticmethod
     def init(app_info: InputAppInfo,
